==> vtk6-6.3.0-4-aarch64.pkg.tar.xz: vtk/vtkImageHistogram.java <==
// java wrapper for vtkImageHistogram object
//

package vtk;
import vtk.*;

public class vtkImageHistogram extends vtkThreadedImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetActiveComponent_2(int id0);
  public void SetActiveComponent(int id0)
    { SetActiveComponent_2(id0); }

  private native int GetActiveComponent_3();
  public int GetActiveComponent()
    { return GetActiveComponent_3(); }

  private native void SetAutomaticBinning_4(int id0);
  public void SetAutomaticBinning(int id0)
    { SetAutomaticBinning_4(id0); }

  private native void AutomaticBinningOn_5();
  public void AutomaticBinningOn()
    { AutomaticBinningOn_5(); }

  private native void AutomaticBinningOff_6();
  public void AutomaticBinningOff()
    { AutomaticBinningOff_6(); }

  private native int GetAutomaticBinning_7();
  public int GetAutomaticBinning()
    { return GetAutomaticBinning_7(); }

  private native void SetMaximumNumberOfBins_8(int id0);
  public void SetMaximumNumberOfBins(int id0)
    { SetMaximumNumberOfBins_8(id0); }

  private native int GetMaximumNumberOfBins_9();
  public int GetMaximumNumberOfBins()
    { return GetMaximumNumberOfBins_9(); }

  private native void SetNumberOfBins_10(int id0);
  public void SetNumberOfBins(int id0)
    { SetNumberOfBins_10(id0); }

  private native int GetNumberOfBins_11();
  public int GetNumberOfBins()
    { return GetNumberOfBins_11(); }

  private native void SetBinOrigin_12(double id0);
  public void SetBinOrigin(double id0)
    { SetBinOrigin_12(id0); }

  private native double GetBinOrigin_13();
  public double GetBinOrigin()
    { return GetBinOrigin_13(); }

  private native void SetBinSpacing_14(double id0);
  public void SetBinSpacing(double id0)
    { SetBinSpacing_14(id0); }

  private native double GetBinSpacing_15();
  public double GetBinSpacing()
    { return GetBinSpacing_15(); }

  private native void SetStencilData_16(vtkImageStencilData id0);
  public void SetStencilData(vtkImageStencilData id0)
    { SetStencilData_16(id0); }

  private native long GetStencil_17();
  public vtkImageStencilData GetStencil() {
    long temp = GetStencil_17();

    if (temp == 0) return null;
    return (vtkImageStencilData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetStencilConnection_18(vtkAlgorithmOutput id0);
  public void SetStencilConnection(vtkAlgorithmOutput id0)
    { SetStencilConnection_18(id0); }

  private native void SetGenerateHistogramImage_19(int id0);
  public void SetGenerateHistogramImage(int id0)
    { SetGenerateHistogramImage_19(id0); }

  private native void GenerateHistogramImageOn_20();
  public void GenerateHistogramImageOn()
    { GenerateHistogramImageOn_20(); }

  private native void GenerateHistogramImageOff_21();
  public void GenerateHistogramImageOff()
    { GenerateHistogramImageOff_21(); }

  private native int GetGenerateHistogramImage_22();
  public int GetGenerateHistogramImage()
    { return GetGenerateHistogramImage_22(); }

  private native void SetHistogramImageSize_23(int id0,int id1);
  public void SetHistogramImageSize(int id0,int id1)
    { SetHistogramImageSize_23(id0,id1); }

  private native void SetHistogramImageSize_24(int id0[]);
  public void SetHistogramImageSize(int id0[])
    { SetHistogramImageSize_24(id0); }

  private native int[]  GetHistogramImageSize_25();
  public int[]  GetHistogramImageSize()
    { return GetHistogramImageSize_25(); }

  private native void SetHistogramImageScale_26(int id0);
  public void SetHistogramImageScale(int id0)
    { SetHistogramImageScale_26(id0); }

  private native int GetHistogramImageScaleMinValue_27();
  public int GetHistogramImageScaleMinValue()
    { return GetHistogramImageScaleMinValue_27(); }

  private native int GetHistogramImageScaleMaxValue_28();
  public int GetHistogramImageScaleMaxValue()
    { return GetHistogramImageScaleMaxValue_28(); }

  private native void SetHistogramImageScaleToLinear_29();
  public void SetHistogramImageScaleToLinear()
    { SetHistogramImageScaleToLinear_29(); }

  private native void SetHistogramImageScaleToLog_30();
  public void SetHistogramImageScaleToLog()
    { SetHistogramImageScaleToLog_30(); }

  private native void SetHistogramImageScaleToSqrt_31();
  public void SetHistogramImageScaleToSqrt()
    { SetHistogramImageScaleToSqrt_31(); }

  private native int GetHistogramImageScale_32();
  public int GetHistogramImageScale()
    { return GetHistogramImageScale_32(); }

  private native String GetHistogramImageScaleAsString_33();
  public String GetHistogramImageScaleAsString()
    { return GetHistogramImageScaleAsString_33(); }

  private native long GetHistogram_34();
  public vtkIdTypeArray GetHistogram() {
    long temp = GetHistogram_34();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetTotal_35();
  public int GetTotal()
    { return GetTotal_35(); }

  public vtkImageHistogram() { super(); }

  public vtkImageHistogram(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-18-aarch64.pkg.tar.xz: vtk/vtkImageHistogram.java <==
// java wrapper for vtkImageHistogram object
//

package vtk;
import vtk.*;

public class vtkImageHistogram extends vtkThreadedImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetActiveComponent_2(int id0);
  public void SetActiveComponent(int id0)
    { SetActiveComponent_2(id0); }

  private native int GetActiveComponent_3();
  public int GetActiveComponent()
    { return GetActiveComponent_3(); }

  private native void SetAutomaticBinning_4(int id0);
  public void SetAutomaticBinning(int id0)
    { SetAutomaticBinning_4(id0); }

  private native void AutomaticBinningOn_5();
  public void AutomaticBinningOn()
    { AutomaticBinningOn_5(); }

  private native void AutomaticBinningOff_6();
  public void AutomaticBinningOff()
    { AutomaticBinningOff_6(); }

  private native int GetAutomaticBinning_7();
  public int GetAutomaticBinning()
    { return GetAutomaticBinning_7(); }

  private native void SetMaximumNumberOfBins_8(int id0);
  public void SetMaximumNumberOfBins(int id0)
    { SetMaximumNumberOfBins_8(id0); }

  private native int GetMaximumNumberOfBins_9();
  public int GetMaximumNumberOfBins()
    { return GetMaximumNumberOfBins_9(); }

  private native void SetNumberOfBins_10(int id0);
  public void SetNumberOfBins(int id0)
    { SetNumberOfBins_10(id0); }

  private native int GetNumberOfBins_11();
  public int GetNumberOfBins()
    { return GetNumberOfBins_11(); }

  private native void SetBinOrigin_12(double id0);
  public void SetBinOrigin(double id0)
    { SetBinOrigin_12(id0); }

  private native double GetBinOrigin_13();
  public double GetBinOrigin()
    { return GetBinOrigin_13(); }

  private native void SetBinSpacing_14(double id0);
  public void SetBinSpacing(double id0)
    { SetBinSpacing_14(id0); }

  private native double GetBinSpacing_15();
  public double GetBinSpacing()
    { return GetBinSpacing_15(); }

  private native void SetStencilData_16(vtkImageStencilData id0);
  public void SetStencilData(vtkImageStencilData id0)
    { SetStencilData_16(id0); }

  private native long GetStencil_17();
  public vtkImageStencilData GetStencil() {
    long temp = GetStencil_17();

    if (temp == 0) return null;
    return (vtkImageStencilData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetStencilConnection_18(vtkAlgorithmOutput id0);
  public void SetStencilConnection(vtkAlgorithmOutput id0)
    { SetStencilConnection_18(id0); }

  private native void SetGenerateHistogramImage_19(int id0);
  public void SetGenerateHistogramImage(int id0)
    { SetGenerateHistogramImage_19(id0); }

  private native void GenerateHistogramImageOn_20();
  public void GenerateHistogramImageOn()
    { GenerateHistogramImageOn_20(); }

  private native void GenerateHistogramImageOff_21();
  public void GenerateHistogramImageOff()
    { GenerateHistogramImageOff_21(); }

  private native int GetGenerateHistogramImage_22();
  public int GetGenerateHistogramImage()
    { return GetGenerateHistogramImage_22(); }

  private native void SetHistogramImageSize_23(int id0,int id1);
  public void SetHistogramImageSize(int id0,int id1)
    { SetHistogramImageSize_23(id0,id1); }

  private native void SetHistogramImageSize_24(int id0[]);
  public void SetHistogramImageSize(int id0[])
    { SetHistogramImageSize_24(id0); }

  private native int[]  GetHistogramImageSize_25();
  public int[]  GetHistogramImageSize()
    { return GetHistogramImageSize_25(); }

  private native void SetHistogramImageScale_26(int id0);
  public void SetHistogramImageScale(int id0)
    { SetHistogramImageScale_26(id0); }

  private native int GetHistogramImageScaleMinValue_27();
  public int GetHistogramImageScaleMinValue()
    { return GetHistogramImageScaleMinValue_27(); }

  private native int GetHistogramImageScaleMaxValue_28();
  public int GetHistogramImageScaleMaxValue()
    { return GetHistogramImageScaleMaxValue_28(); }

  private native void SetHistogramImageScaleToLinear_29();
  public void SetHistogramImageScaleToLinear()
    { SetHistogramImageScaleToLinear_29(); }

  private native void SetHistogramImageScaleToLog_30();
  public void SetHistogramImageScaleToLog()
    { SetHistogramImageScaleToLog_30(); }

  private native void SetHistogramImageScaleToSqrt_31();
  public void SetHistogramImageScaleToSqrt()
    { SetHistogramImageScaleToSqrt_31(); }

  private native int GetHistogramImageScale_32();
  public int GetHistogramImageScale()
    { return GetHistogramImageScale_32(); }

  private native String GetHistogramImageScaleAsString_33();
  public String GetHistogramImageScaleAsString()
    { return GetHistogramImageScaleAsString_33(); }

  private native long GetHistogram_34();
  public vtkIdTypeArray GetHistogram() {
    long temp = GetHistogram_34();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetTotal_35();
  public int GetTotal()
    { return GetTotal_35(); }

  public vtkImageHistogram() { super(); }

  public vtkImageHistogram(long id) { super(id); }
  public native long   VTKInit();

}
